==> libpgjava_42.3.3.orig.tar.gz: postgresql-42.3.3-jdbc-src/src/test/java/org/postgresql/test/util/HostSpecTest.java <==
/*
 * Copyright (c) 2017, PostgreSQL Global Development Group
 * See the LICENSE file in the project root for more information.
 */

package org.postgresql.test.util;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import org.postgresql.util.HostSpec;

import org.junit.After;
import org.junit.Test;

/**
 * @author Joe Kutner on 10/19/17.
 *         Twitter: @codefinger
 */
public class HostSpecTest {

  @After
  public void cleanup() {
    System.clearProperty("socksProxyHost");
    System.clearProperty("socksProxyPort");
    System.clearProperty("socksNonProxyHosts");
  }

  @Test
  public void testShouldResolve() throws Exception {
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithEmptySocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithWhiteSpaceSocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", " ");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithSocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertFalse(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithSocksProxyHostWithLocalhost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithSocksNonProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithSocksNonProxyHosts() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com|localhost");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldResolveWithSocksNonProxyHostsNotMatching() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com|localhost");
    HostSpec hostSpec = new HostSpec("example.org", 5432);
    assertFalse(hostSpec.shouldResolve());
  }

  @Test
  public void testShouldReturnEmptyLocalAddressBind() throws Exception {
    HostSpec hostSpec = new HostSpec("example.org", 5432);
    assertNull(hostSpec.getLocalSocketAddress());
  }

  @Test
  public void testShouldReturnLocalAddressBind() throws Exception {
    HostSpec hostSpec = new HostSpec("example.org", 5432, "foo");
    assertEquals("foo", hostSpec.getLocalSocketAddress());
  }
}

==> libpgjava_42.7.7.orig.tar.gz: postgresql-42.7.7-jdbc-src/src/test/java/org/postgresql/test/util/HostSpecTest.java <==
/*
 * Copyright (c) 2017, PostgreSQL Global Development Group
 * See the LICENSE file in the project root for more information.
 */

package org.postgresql.test.util;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.postgresql.util.HostSpec;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Test;

/**
 * @author Joe Kutner on 10/19/17.
 *         Twitter: @codefinger
 */
class HostSpecTest {

  @AfterEach
  void cleanup() {
    System.clearProperty("socksProxyHost");
    System.clearProperty("socksProxyPort");
    System.clearProperty("socksNonProxyHosts");
  }

  @Test
  void shouldResolve() throws Exception {
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithEmptySocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithWhiteSpaceSocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", " ");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithSocksProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertFalse(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithSocksProxyHostWithLocalhost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    HostSpec hostSpec = new HostSpec("localhost", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithSocksNonProxyHost() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithSocksNonProxyHosts() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com|localhost");
    HostSpec hostSpec = new HostSpec("example.com", 5432);
    assertTrue(hostSpec.shouldResolve());
  }

  @Test
  void shouldResolveWithSocksNonProxyHostsNotMatching() throws Exception {
    System.setProperty("socksProxyHost", "fake-socks-proxy");
    System.setProperty("socksNonProxyHosts", "example.com|localhost");
    HostSpec hostSpec = new HostSpec("example.org", 5432);
    assertFalse(hostSpec.shouldResolve());
  }

  @Test
  void shouldReturnEmptyLocalAddressBind() throws Exception {
    HostSpec hostSpec = new HostSpec("example.org", 5432);
    assertNull(hostSpec.getLocalSocketAddress());
  }

  @Test
  void shouldReturnLocalAddressBind() throws Exception {
    HostSpec hostSpec = new HostSpec("example.org", 5432, "foo");
    assertEquals("foo", hostSpec.getLocalSocketAddress());
  }
}
